summaryrefslogtreecommitdiffstats
path: root/karm/taskview.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:14:12 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:14:12 -0600
commitfd5d099065a748cac49e20a13481f85666c53c71 (patch)
treea0f1672cd88eb0e69b9ddc2ed9b08ecd98538bd3 /karm/taskview.cpp
parentb440a9c608596cd88efdb3bfa4661c5e37efbe4b (diff)
downloadtdepim-fd5d099065a748cac49e20a13481f85666c53c71.tar.gz
tdepim-fd5d099065a748cac49e20a13481f85666c53c71.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'karm/taskview.cpp')
-rw-r--r--karm/taskview.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/karm/taskview.cpp b/karm/taskview.cpp
index bcabad37..14477cf5 100644
--- a/karm/taskview.cpp
+++ b/karm/taskview.cpp
@@ -37,7 +37,7 @@
class DesktopTracker;
-TaskView::TaskView(TQWidget *parent, const char *name, const TQString &icsfile ):KListView(parent,name)
+TaskView::TaskView(TQWidget *parent, const char *name, const TQString &icsfile ):TDEListView(parent,name)
{
_preferences = Preferences::instance( icsfile );
_storage = KarmStorage::instance();
@@ -119,10 +119,10 @@ KarmStorage* TaskView::storage()
void TaskView::contentsMousePressEvent ( TQMouseEvent * e )
{
kdDebug(5970) << "entering contentsMousePressEvent" << endl;
- KListView::contentsMousePressEvent(e);
+ TDEListView::contentsMousePressEvent(e);
Task* task = current_item();
// This checks that there has been a click onto an item,
// not into an empty part of the KListView.
if ( task != 0 && // zero can happen if there is no task
e->pos().y() >= current_item()->itemPos() &&
e->pos().y() < current_item()->itemPos()+current_item()->height() )
@@ -145,7 +145,7 @@ void TaskView::contentsMouseDoubleClickEvent ( TQMouseEvent * e )
// not in the blank space, if yes, stop all other tasks and start the new timer.
{
kdDebug(5970) << "entering contentsMouseDoubleClickEvent" << endl;
- KListView::contentsMouseDoubleClickEvent(e);
+ TDEListView::contentsMouseDoubleClickEvent(e);
Task *task = current_item();
@@ -119,10 +119,10 @@ KarmStorage* TaskView::storage()
Task* task = current_item();
// This checks that there has been a click onto an item,
- // not into an empty part of the KListView.
+ // not into an empty part of the TDEListView.
if ( task != 0 && // zero can happen if there is no task
e->pos().y() >= current_item()->itemPos() &&